==> DateTime-Locale-1.24.tar.gz: DateTime-Locale-1.24/share/fr-WF.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "E",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    H => "HH 'h'",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E dd/MM",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'semaine' W (MMMM)",
    "MMMMW-count-other" => "'semaine' W (MMMM)",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E dd/MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'semaine' w 'de' Y",
    "yw-count-other" => "'semaine' w 'de' Y",
  },
  code => "fr-WF",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} '\N{U+00e0}' {0}",
  datetime_format_long => "{1} '\N{U+00e0}' {0}",
  datetime_format_medium => "{1} '\N{U+00e0}' {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jeu.",
    "ven.",
    "sam.",
    "dim.",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "lundi",
    "mardi",
    "mercredi",
    "jeudi",
    "vendredi",
    "samedi",
    "dimanche",
  ],
  day_stand_alone_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jeu.",
    "ven.",
    "sam.",
    "dim.",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "lundi",
    "mardi",
    "mercredi",
    "jeudi",
    "vendredi",
    "samedi",
    "dimanche",
  ],
  era_abbreviated => [
    "av. J.-C.",
    "ap. J.-C.",
  ],
  era_narrow => [
    "av. J.-C.",
    "ap. J.-C.",
  ],
  era_wide => [
    "avant J\N{U+00e9}sus-Christ",
    "apr\N{U+00e8}s J\N{U+00e9}sus-Christ",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "French",
  month_format_abbreviated => [
    "janv.",
    "f\N{U+00e9}vr.",
    "mars",
    "avr.",
    "mai",
    "juin",
    "juil.",
    "ao\N{U+00fb}t",
    "sept.",
    "oct.",
    "nov.",
    "d\N{U+00e9}c.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "janvier",
    "f\N{U+00e9}vrier",
    "mars",
    "avril",
    "mai",
    "juin",
    "juillet",
    "ao\N{U+00fb}t",
    "septembre",
    "octobre",
    "novembre",
    "d\N{U+00e9}cembre",
  ],
  month_stand_alone_abbreviated => [
    "janv.",
    "f\N{U+00e9}vr.",
    "mars",
    "avr.",
    "mai",
    "juin",
    "juil.",
    "ao\N{U+00fb}t",
    "sept.",
    "oct.",
    "nov.",
    "d\N{U+00e9}c.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "janvier",
    "f\N{U+00e9}vrier",
    "mars",
    "avril",
    "mai",
    "juin",
    "juillet",
    "ao\N{U+00fb}t",
    "septembre",
    "octobre",
    "novembre",
    "d\N{U+00e9}cembre",
  ],
  name => "French Wallis & Futuna",
  native_language => "fran\N{U+00e7}ais",
  native_name => "fran\N{U+00e7}ais Wallis-et-Futuna",
  native_script => undef,
  native_territory => "Wallis-et-Futuna",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1er trimestre",
    "2e trimestre",
    "3e trimestre",
    "4e trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1er trimestre",
    "2e trimestre",
    "3e trimestre",
    "4e trimestre",
  ],
  script => undef,
  territory => "Wallis & Futuna",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 35,
}

==> DateTime-Locale-1.34.tar.gz: DateTime-Locale-1.34/share/fr-WF.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "E",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "dd/MM/y GGGGG",
    H => "HH 'h'",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E dd/MM",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-one" => "'semaine' W (MMMM)",
    "MMMMW-count-other" => "'semaine' W (MMMM)",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "dd/MM",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM/y",
    yMEd => "E dd/MM/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "dd/MM/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'semaine' w 'de' Y",
    "yw-count-other" => "'semaine' w 'de' Y",
  },
  code => "fr-WF",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "dd/MM/y",
  datetime_format_full => "{1} '\N{U+00e0}' {0}",
  datetime_format_long => "{1} '\N{U+00e0}' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jeu.",
    "ven.",
    "sam.",
    "dim.",
  ],
  day_format_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_format_wide => [
    "lundi",
    "mardi",
    "mercredi",
    "jeudi",
    "vendredi",
    "samedi",
    "dimanche",
  ],
  day_stand_alone_abbreviated => [
    "lun.",
    "mar.",
    "mer.",
    "jeu.",
    "ven.",
    "sam.",
    "dim.",
  ],
  day_stand_alone_narrow => [
    "L",
    "M",
    "M",
    "J",
    "V",
    "S",
    "D",
  ],
  day_stand_alone_wide => [
    "lundi",
    "mardi",
    "mercredi",
    "jeudi",
    "vendredi",
    "samedi",
    "dimanche",
  ],
  era_abbreviated => [
    "av. J.-C.",
    "ap. J.-C.",
  ],
  era_narrow => [
    "av. J.-C.",
    "ap. J.-C.",
  ],
  era_wide => [
    "avant J\N{U+00e9}sus-Christ",
    "apr\N{U+00e8}s J\N{U+00e9}sus-Christ",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "French",
  month_format_abbreviated => [
    "janv.",
    "f\N{U+00e9}vr.",
    "mars",
    "avr.",
    "mai",
    "juin",
    "juil.",
    "ao\N{U+00fb}t",
    "sept.",
    "oct.",
    "nov.",
    "d\N{U+00e9}c.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "janvier",
    "f\N{U+00e9}vrier",
    "mars",
    "avril",
    "mai",
    "juin",
    "juillet",
    "ao\N{U+00fb}t",
    "septembre",
    "octobre",
    "novembre",
    "d\N{U+00e9}cembre",
  ],
  month_stand_alone_abbreviated => [
    "janv.",
    "f\N{U+00e9}vr.",
    "mars",
    "avr.",
    "mai",
    "juin",
    "juil.",
    "ao\N{U+00fb}t",
    "sept.",
    "oct.",
    "nov.",
    "d\N{U+00e9}c.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "janvier",
    "f\N{U+00e9}vrier",
    "mars",
    "avril",
    "mai",
    "juin",
    "juillet",
    "ao\N{U+00fb}t",
    "septembre",
    "octobre",
    "novembre",
    "d\N{U+00e9}cembre",
  ],
  name => "French Wallis & Futuna",
  native_language => "fran\N{U+00e7}ais",
  native_name => "fran\N{U+00e7}ais Wallis-et-Futuna",
  native_script => undef,
  native_territory => "Wallis-et-Futuna",
  native_variant => undef,
  quarter_format_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1er trimestre",
    "2e trimestre",
    "3e trimestre",
    "4e trimestre",
  ],
  quarter_stand_alone_abbreviated => [
    "T1",
    "T2",
    "T3",
    "T4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1er trimestre",
    "2e trimestre",
    "3e trimestre",
    "4e trimestre",
  ],
  script => undef,
  territory => "Wallis & Futuna",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 41,
}
